@@ -221,6 +221,15 @@ class Categoria(MPTTModel):
     def natural_key(self):
         return self.nome
 
+    def _validate_unique(self):
+        """Valida se o objeto inserido é único para a url. Esta função é
+        usada apenas quando o objeto é salvo no banco.
+        """
+        if Categoria.objects.exclude(pk=self.pk) \
+                .filter(url=self.url, url__isnull=False,
+                        conta_id=self.conta_id).count():
+            raise ValidationError({'url': [u'Uma categoria com a mesma URL já existe.']})
+
     def save(self, *args, **kwargs):
         if isinstance(self.parent, basestring):
             self.parent_id = int(self.parent)
@@ -235,6 +244,11 @@ class Categoria(MPTTModel):
         if self.conta.id and not self.contrato_id:
             self.contrato_id = self.conta.contrato_id
 
+        try:
+            self._validate_unique()
+        except ValidationError:
+            self.url = '%s-%s' % (self.url, time.strftime("%Y-%m-%d-%H-%M-%S"))
+
         super(Categoria, self).save(*args, **kwargs)
 
     def ancestrais(self, *args, **kwargs):
@@ -318,10 +332,14 @@ class Categoria(MPTTModel):
         else:
             url = self.url
 
-        if str(url)[:1] == '/':
-            return str(url)[1:]
-        else:
-            return str(url)
+        try:
+            string = str(url)
+        except UnicodeEncodeError:
+            string = utils.to_ascii(url)
+
+        if string[:1] == '/':
+            return string[1:]
+        return string
 
     def adicionar_url(self, url):
         from repositories.plataforma.models import URL
@@ -354,23 +372,34 @@ class Categoria(MPTTModel):
                 self._seo = None
         return self._seo
 
-    def atualizar_url(self, path_url):
+    def atualizar_url(self, url=None):
         from repositories.plataforma.models import URL
 
-        if not path_url:
-            path_url = '/' + slugify(self.nome)
+        if url:
+            path_url = url
+        else:
+            my_url = URL.objects.filter(categoria=self, principal=True)[:1]
+
+            if my_url.__len__() > 0:
+                url = my_url[0].url
+            else:
+                if self.url is None:
+                    self.url = '{}'.format(time.strftime("%Y-%m-%d-%H-%M-%S"))
+
+                url = "/{}".format(self.url)
+
+            path_url = url
 
         def criar_url(path_url):
-
-            # TODO: Isso aqui deve ficar a cargo do catalogo. Colocado um try para quebra galho e parar
-            # de dar erro com frequencia.
             try:
                 url, primeira_url = URL.objects.get_or_create(url=path_url, categoria=self, conta=self.conta)
+            except IntegrityError as e:
+                raise e
             except TransactionManagementError:
                 time.sleep(1)
                 url, primeira_url = URL.objects.get_or_create(url=path_url, categoria=self, conta=self.conta)
-
-            return url
+            else:
+                return url
 
         def adicionar_traco(s):
             try:
@@ -392,9 +421,17 @@ class Categoria(MPTTModel):
         while True:
             contagem += 1
 
-            # Caso a iteração seja maior que 10 retorna o erro para o lojista.
+            # Caso a iteração seja maior que 10 é criada a url como:
+            # /categoria/nome-timestamp.html
             if contagem >= 10:
-                return False
+                try:
+                    url_obj = criar_url("/categoria" + self.url.strip() + ".html")
+                    URL.objects.filter(categoria=self) \
+                        .exclude(pk=url_obj.id) \
+                        .update(principal=False)
+                    break
+                except Exception as e:
+                    return False
 
             try:
                 url_obj = criar_url(path_url)
