@@ -74,8 +74,8 @@ class Cliente(models.Model):
     senha = models.CharField(db_column="cliente_senha", max_length=64)
     nome = models.CharField(db_column="cliente_nome", max_length=255, null=True)
     sexo = models.CharField(db_column="cliente_sexo", max_length=1, null=True)
-    telefone_principal = models.CharField(db_column="cliente_telefone_principal", max_length=11, null=True)
-    telefone_comercial = models.CharField(db_column="cliente_telefone_comercial", max_length=11, null=True)
+    telefone_principal = models.CharField(db_column="cliente_telefone_principal", max_length=11, null=True, blank=True)
+    telefone_comercial = models.CharField(db_column="cliente_telefone_comercial", max_length=11, null=True, blank=True)
     telefone_celular = models.CharField(db_column="cliente_telefone_celular", max_length=11, null=True)
     newsletter = models.BooleanField(db_column="cliente_newsletter", default=True)
     data_nascimento = models.DateField(db_column="cliente_data_nascimento", null=True)
